@@ -39,8 +39,8 @@ from __future__ import unicode_literals
 from django.core import validators
 from django.contrib.auth import get_user_model
 from django.contrib.auth.hashers import is_password_usable
+from django.db import transaction
 from django.template.defaultfilters import slugify
-from django.utils import six
 from django.utils.translation import ugettext_lazy as _
 from django.urls.exceptions import NoReverseMatch
 from rest_framework import serializers
@@ -49,13 +49,13 @@ from rest_framework.generics import get_object_or_404
 from django_countries.serializer_fields import CountryField
 
 from .. import settings
+from ..compat import reverse, six
 from ..decorators import _valid_manager
 from ..humanize import as_money
 from ..mixins import as_html_description, product_url
-from ..models import (BalanceLine, CartItem, Charge, Plan,
+from ..models import (AdvanceDiscount, BalanceLine, CartItem, Charge, Plan,
     RoleDescription, Subscription, Transaction)
 from ..utils import (build_absolute_uri, get_organization_model, get_role_model)
-from ..compat import reverse
 
 #pylint: disable=no-init
 
@@ -244,10 +244,10 @@ class TableSerializer(NoModelSerializer):
 
 class MetricsSerializer(NoModelSerializer):
 
-    scale = serializers.FloatField(
+    scale = serializers.FloatField(required=False,
         help_text=_("The scale of the number reported in the tables (ex: 1000"\
         " when numbers are reported in thousands of dollars)"))
-    unit = serializers.CharField(
+    unit = serializers.CharField(required=False,
         help_text=_("Three-letter ISO 4217 code for currency unit (ex: usd)"))
     title = serializers.CharField(
         help_text=_("Title for the table"))
@@ -330,6 +330,8 @@ class OrganizationDetailSerializer(OrganizationSerializer):
         help_text=_("Zip/Postal code"))
     country = CountryField(required=False, allow_blank=True,
         help_text=_("Country"))
+    is_bulk_buyer = serializers.BooleanField(required=False, default=False,
+        help_text=_("Enable GroupBuy"))
     extra = serializers.CharField(required=False, allow_null=True,
         help_text=_("Extra meta data (can be stringify JSON)"))
 
@@ -408,6 +410,8 @@ class WithSubscriptionSerializer(serializers.ModelSerializer):
 
 class OrganizationWithSubscriptionsSerializer(OrganizationDetailSerializer):
 
+    is_bulk_buyer = serializers.BooleanField(required=False, default=False,
+        help_text=_("Enable GroupBuy"))
     subscriptions = WithSubscriptionSerializer(
         source='subscription_set', many=True, read_only=True)
 
@@ -437,6 +441,16 @@ class OrganizationWithEndsAtByPlanSerializer(serializers.ModelSerializer):
         read_only_fields = ('slug', 'created_at')
 
 
+class AdvanceDiscountSerializer(serializers.ModelSerializer):
+
+    discount_type = EnumField(choices=AdvanceDiscount.DISCOUNT_CHOICES,
+        help_text=_("Type of discount (periods, percentage or currency unit)"))
+
+    class Meta:
+        model = AdvanceDiscount
+        fields = ('discount_type', 'discount_value', 'length')
+
+
 class PlanSerializer(serializers.ModelSerializer):
 
     title = serializers.CharField(required=False,
@@ -455,8 +469,7 @@ class PlanSerializer(serializers.ModelSerializer):
     renewal_type = EnumField(choices=Plan.RENEWAL_CHOICES, required=False,
         help_text=_("Natural period for the subscription"))
     app_url = serializers.SerializerMethodField()
-    organization = serializers.SlugRelatedField(
-        read_only=True, slug_field='slug',
+    organization = OrganizationSerializer(read_only=True,
         help_text=_("Provider of the plan"))
     skip_optin_on_grant = serializers.BooleanField(required=False,
         help_text=_("True when a subscriber can automatically be subscribed"\
@@ -465,21 +478,60 @@ class PlanSerializer(serializers.ModelSerializer):
     optin_on_request = serializers.BooleanField(required=False,
         help_text=_("True when a provider must manually accept a subscription"\
         " to the plan initiated by a subscriber. (defaults to False)"))
+    advance_discounts = AdvanceDiscountSerializer(many=True, required=False,
+        help_text=_("Discounts when periods are paid in advance."))
+    discounted_period_amount = serializers.SerializerMethodField(required=False,
+        help_text=_("Discounted amount for the first period"))
 
     class Meta:
         model = Plan
         fields = ('slug', 'title', 'description', 'is_active',
                   'setup_amount', 'period_amount', 'period_type', 'app_url',
-                  'advance_discount', 'unit', 'organization', 'extra',
+                  'advance_discounts', 'unit', 'organization', 'extra',
                   'period_length', 'renewal_type', 'is_not_priced',
                   'created_at',
-                  'skip_optin_on_grant', 'optin_on_request')
+                  'skip_optin_on_grant', 'optin_on_request',
+                  'discounted_period_amount')
         read_only_fields = ('slug', 'app_url')
 
+    @staticmethod
+    def get_discounted_period_amount(obj):
+        return getattr(obj, 'discounted_period_amount', obj.period_amount)
+
     @staticmethod
     def get_app_url(obj):
         return product_url(obj.organization)
 
+    def create(self, validated_data):
+        advance_discounts = validated_data.pop('advance_discounts', [])
+        with transaction.atomic():
+            instance = Plan.objects.create(**validated_data)
+            for advance_discount in advance_discounts:
+                AdvanceDiscount.objects.create(
+                    plan=instance,
+                    discount_type=advance_discount.get('discount_type'),
+                    discount_value=advance_discount.get('discount_value'),
+                    length=advance_discount.get('length'))
+
+        return instance
+
+    def update(self, instance, validated_data):
+        advance_discounts = validated_data.pop('advance_discounts', [])
+        for attr, value in six.iteritems(validated_data):
+            setattr(instance, attr, value)
+
+        with transaction.atomic():
+            instance.save()
+            instance.advance_discounts.all().delete()
+            for advance_discount in advance_discounts:
+                AdvanceDiscount.objects.create(
+                    plan=instance,
+                    discount_type=advance_discount.get('discount_type'),
+                    discount_value=advance_discount.get('discount_value'),
+                    length=advance_discount.get('length'))
+
+        return instance
+
     def validate_title(self, title):
         kwargs = {}
         if 'provider' in self.context:
@@ -639,7 +691,9 @@ class RoleDescriptionSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = RoleDescription
-        fields = ('created_at', 'title', 'slug', 'is_global', 'organization')
+        fields = ('created_at', 'slug', 'title',
+                  'skip_optin_on_grant', 'implicit_create_on_none',
+                  'is_global', 'organization', 'extra')
         read_only_fields = ('created_at', 'slug', 'is_global')
 
 
