@@ -86,6 +86,7 @@ _SETTINGS = {
         'BUILD_ABSOLUTE_URI_CALLABLE': None,
         'FEE_PERCENTAGE': 0
     },
+    'BYPASS_IMPLICIT_GRANT': {},
     'BYPASS_PERMISSION_CHECK': False,
     # Do not check the auth token against the processor to set processor keys.
     # (useful while testing).
@@ -131,6 +132,7 @@ BROKER_CALLABLE = _SETTINGS.get('BROKER').get('GET_INSTANCE', None)
 BROKER_FEE_PERCENTAGE = _SETTINGS.get('BROKER').get('FEE_PERCENTAGE', 0)
 BUILD_ABSOLUTE_URI_CALLABLE = _SETTINGS.get('BROKER').get(
     'BUILD_ABSOLUTE_URI_CALLABLE')
+BYPASS_IMPLICIT_GRANT = _SETTINGS.get('BYPASS_IMPLICIT_GRANT')
 BYPASS_PROCESSOR_AUTH = _SETTINGS.get('BYPASS_PROCESSOR_AUTH')
 CREDIT_ON_CREATE = _SETTINGS.get('CREDIT_ON_CREATE')
 DEFAULT_UNIT = _SETTINGS.get('DEFAULT_UNIT')
