@@ -1,4 +1,4 @@
-# Copyright (c) 2019, DjaoDjin inc.
+# Copyright (c) 2020, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -33,20 +33,21 @@ from decimal import Decimal
 from io import BytesIO, StringIO
 
 from django.http import HttpResponse
-from django.utils import six
+from django.template.defaultfilters import slugify
 from django.views.generic import View
 from rest_framework.generics import get_object_or_404
 from rest_framework.request import Request
 
+from .. import humanize
 from ..api.coupons import CouponQuerysetMixin, SmartCouponListMixin
-from ..mixins import CartItemSmartListMixin, ProviderMixin
 from ..api.transactions import (BillingsQuerysetMixin,
     SmartTransactionListMixin, TransactionQuerysetMixin, TransferQuerysetMixin)
 from ..api.users import RegisteredQuerysetMixin
-from .. import humanize
+from ..compat import six
 from ..managers.metrics import (abs_monthly_balances, monthly_balances,
     month_periods)
-from ..mixins import (MetricsMixin, ChurnedQuerysetMixin,
+from ..mixins import (CartItemSmartListMixin, ProviderMixin,
+    MetricsMixin, ChurnedQuerysetMixin,
     SubscriptionSmartListMixin, SubscribedQuerysetMixin, UserSmartListMixin)
 from ..models import BalanceLine, CartItem, Coupon
 from ..utils import datetime_or_now
@@ -142,7 +143,8 @@ class CouponDownloadView(SmartCouponListMixin, CouponQuerysetMixin,
     headings = [
         'Created At'
         'Code',
-        'Percentage',
+        'DiscountType',
+        'Amount',
     ]
 
     def get_headings(self):
@@ -166,7 +168,8 @@ class CartItemDownloadView(CartItemSmartListMixin, CartItemQuerysetMixin,
     headings = [
         'Used At',
         'Code',
-        'Percentage',
+        'DiscountType',
+        'Amount',
         'Name',
         'Email',
         'Plan',
@@ -216,7 +219,9 @@ class CartItemDownloadView(CartItemSmartListMixin, CartItemQuerysetMixin,
         return [
             cartitem.created_at.date(),
             self.encode(cartitem.coupon.code),
-            cartitem.coupon.percent,
+            slugify(
+                Coupon.DISCOUNT_CHOICES[cartitem.coupon.discount_type - 1][1]),
+            cartitem.coupon.discount_value,
             self.encode(full_name),
             self.encode(email),
             self.encode(cartitem.plan.slug),
