@@ -1,4 +1,4 @@
-# Copyright (c) 2019, DjaoDjin inc.
+# Copyright (c) 2020, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -130,8 +130,7 @@ djaodjin-saas/tree/master/saas/templates/saas/pricing.html>`__).
                 setattr(plan, 'is_line_break', True)
             if redeemed and redeemed.is_valid(plan):
                 setattr(plan, 'discounted_period_price',
-                    # XXX integer division
-                    plan.discounted_price(redeemed.percent))
+                    plan.get_discounted_period_price(redeemed))
             if is_authenticated(self.request):
                 setattr(plan, 'managed_subscribers',
                     get_role_model().objects.role_on_subscriber(
